@@ -1,3 +1,9 @@
+"""
+NowPayments.io Python Client
+"""
+
+__version__ = "1.6.0"
+
 import hashlib
 import hmac
 import json
@@ -5,25 +11,31 @@ import json
 from nowpayment.apis.currencies import CurrencyAPI
 from nowpayment.apis.payment import PaymentAPI
 from nowpayment.apis.payout import PayoutAPI
+from nowpayment.apis.billing import BillingAPI
 
 
 class NowPayments:
 
-    def __init__(self, api_key: str, jwt_token: str = None):
+    def __init__(self, api_key: str, jwt_token: str = None, timeout = None):
         self.api_key = api_key
         self.jwt_token = jwt_token
+        self.timeout = timeout
 
     @property
     def payment(self):
-        return PaymentAPI(self.api_key, self.jwt_token)
+        return PaymentAPI(self.api_key, jwt_token=self.jwt_token, timeout=self.timeout)
 
     @property
     def currency(self):
-        return CurrencyAPI(self.api_key, self.jwt_token)
+        return CurrencyAPI(self.api_key, jwt_token=self.jwt_token, timeout=self.timeout)
 
     @property
     def payout(self):
-        return PayoutAPI(self.api_key, self.jwt_token)
+        return PayoutAPI(self.api_key, jwt_token=self.jwt_token, timeout=self.timeout)
+
+    @property
+    def billing(self):
+        return BillingAPI(self.api_key, jwt_token=self.jwt_token, timeout=self.timeout)
 
     def get_api_status(self) -> dict:
         """
@@ -44,6 +56,11 @@ class NowPayments:
         :return: True if the signature is valid, False otherwise.
         :rtype: bool
         """
+        if not isinstance(data, dict):
+            raise ValueError("Data must be a dictionary")
+        if not isinstance(ipn_secret, str):
+            raise ValueError("IPN secret must be a string")
+            
         request_data = dict(sorted(data.items()))
         sorted_request_json = json.dumps(request_data, separators=(',', ':'))
         return hmac.new(
